//public packages
import 'dart:core';
import 'package:args/args.dart';

//My stuff
import 'package:dartdoku/domains/sudoku/SudokuProblem.dart';
import 'package:api_dartdoku_client/api_dartdoku_client.dart';

late ArgResults argResults;
String help =
    'Usage: sudoku [OPTION]...\nA simple dart program to generate and display a sudoku game.\n\n  -h, --help          Display this message\n  -i, --initialHints  number of givens on starting board, defaulting to 30';

void main(List<String> arguments) async {
  final parser = ArgParser()
    ..addOption('initialHints',
        abbr: 'i', help: 'number of givens on board', defaultsTo: '17')
    ..addFlag('help', abbr: 'h')
    ..addOption('count', abbr: 'n', defaultsTo: '1')
    ..addOption('url', abbr: 'u', defaultsTo: 'sudoku.rusondia.net')
    ..addOption('scheme', abbr: 's', defaultsTo: 'https')
    ..addOption('port', abbr: 'p', defaultsTo: '443');

  argResults = parser.parse(arguments);

  if (argResults['help']) {
    print(help);
  } else {
    var hints = int.parse(argResults['initialHints']);
    var count = int.parse(argResults['count']);
    var port = int.parse(argResults['port']);
    var scheme = argResults['scheme'];
    var url = argResults['url'];

    var uri = Uri(
        scheme: scheme,
        host: url,
        port: port,
        path: '/api/v1/hints/$hints/count/$count');

    var problems = await getProblemsFromUri(uri);
    for (var problem in problems) {
      print('Initial board');
      print(SudokuProblem.stateToString(problem.getInitialState()));
      print('\nFinal Board');
      print(SudokuProblem.stateToString(problem.getFinalState()));
    }
  }
}
